==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/UnionFactory.h <==
// public abstract class soot.jimple.toolkits.pointer.UnionFactory

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2eacdeb35392377 soot_jimple_toolkits_pointer_UnionFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_UnionFactory_H_
#define _JC_soot_jimple_toolkits_pointer_UnionFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_toolkits_pointer_Union$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_UnionFactory$sub_refs	_jc_soot_jimple_toolkits_pointer_UnionFactory$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_UnionFactory$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_UnionFactory$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_UnionFactory$refs	_jc_soot_jimple_toolkits_pointer_UnionFactory$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_UnionFactory$nonrefs	_jc_soot_jimple_toolkits_pointer_UnionFactory$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_UnionFactory$object	_jc_soot_jimple_toolkits_pointer_UnionFactory$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_UnionFactory$vmethods	_jc_soot_jimple_toolkits_pointer_UnionFactory$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_UnionFactory$vtable	_jc_soot_jimple_toolkits_pointer_UnionFactory$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_UnionFactory$vtype	_jc_soot_jimple_toolkits_pointer_UnionFactory$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_UnionFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_UnionFactory$object *);

// Virtual methods
extern struct _jc_soot_jimple_toolkits_pointer_Union$object *_jc_soot_jimple_toolkits_pointer_UnionFactory$method$newUnion$cadc46e7aeca770e(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_UnionFactory$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_UnionFactory$method_info$newUnion$cadc46e7aeca770e;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$vmethods {
	struct _jc_soot_jimple_toolkits_pointer_Union$object	*(*newUnion$cadc46e7aeca770e)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_UnionFactory$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_UnionFactory$vmethods	soot_jimple_toolkits_pointer_UnionFactory;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_UnionFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$refs {
    _jc_soot_jimple_toolkits_pointer_UnionFactory$sub_refs	soot_jimple_toolkits_pointer_UnionFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_UnionFactory$sub_nonrefs	soot_jimple_toolkits_pointer_UnionFactory;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$object {
	_jc_soot_jimple_toolkits_pointer_UnionFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_UnionFactory$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_UnionFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_UnionFactory$vtype _jc_soot_jimple_toolkits_pointer_UnionFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_UnionFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_UnionFactory$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_UnionFactory_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/UnionFactory.h <==
// public abstract class soot.jimple.toolkits.pointer.UnionFactory

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2eacdeb35392377 soot_jimple_toolkits_pointer_UnionFactory

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_UnionFactory_H_
#define _JC_soot_jimple_toolkits_pointer_UnionFactory_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_toolkits_pointer_Union$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_UnionFactory$sub_refs	_jc_soot_jimple_toolkits_pointer_UnionFactory$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_UnionFactory$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_UnionFactory$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_UnionFactory$refs	_jc_soot_jimple_toolkits_pointer_UnionFactory$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_UnionFactory$nonrefs	_jc_soot_jimple_toolkits_pointer_UnionFactory$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_UnionFactory$object	_jc_soot_jimple_toolkits_pointer_UnionFactory$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_UnionFactory$vmethods	_jc_soot_jimple_toolkits_pointer_UnionFactory$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_UnionFactory$vtable	_jc_soot_jimple_toolkits_pointer_UnionFactory$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_UnionFactory$vtype	_jc_soot_jimple_toolkits_pointer_UnionFactory$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_UnionFactory$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_UnionFactory$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_jimple_toolkits_pointer_Union$object *_jc_soot_jimple_toolkits_pointer_UnionFactory$method$newUnion$cadc46e7aeca770e(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_UnionFactory$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_UnionFactory$method_info$newUnion$cadc46e7aeca770e;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$vmethods {
	struct _jc_soot_jimple_toolkits_pointer_Union$object	*(*newUnion$cadc46e7aeca770e)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_UnionFactory$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_UnionFactory$vmethods	soot_jimple_toolkits_pointer_UnionFactory;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_UnionFactory$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$refs {
    _jc_soot_jimple_toolkits_pointer_UnionFactory$sub_refs	soot_jimple_toolkits_pointer_UnionFactory;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_UnionFactory$sub_nonrefs	soot_jimple_toolkits_pointer_UnionFactory;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_UnionFactory$object {
	_jc_soot_jimple_toolkits_pointer_UnionFactory$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_UnionFactory$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_UnionFactory$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_UnionFactory$vtype _jc_soot_jimple_toolkits_pointer_UnionFactory$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_UnionFactory, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_UnionFactory$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_UnionFactory_H_ */
